@@ -201,18 +201,27 @@ rgrid <- function(loc, dmax, res){
 
 
 ## osrmTable Utils
-distTableFormat <- function(res, src, dst){
+durTableFormat <- function(res, src, dst){
   # extract distance table
   mat <- res$durations
   # From sec to minutes
   mat <- round(mat/(60), 1)
-  # # NA management
-  # mat[mat == 357913.94] <- NA
   # col and row names management
   dimnames(mat) <- list(src$id, dst$id)
   return(mat)
 }  
 
+
+distTableFormat <- function(res, src, dst){
+  # extract distance table
+  mat <- res$distances
+  # rounding meters
+  mat <- round(mat, 0)
+  # col and row names management
+  dimnames(mat) <- list(src$id, dst$id)
+  return(mat)
+} 
+
 coordFormat <- function(res, src, dst){
   sources <- data.frame(matrix(unlist(res$sources$location, 
                                       use.names = T), 
